import { getCurrentScope, onScopeDispose } from "vue";
import { noop } from "./Function";
export class Subscription {
    callbacks = [];
    addSubscription(callback, options = { detached: false, onCleanup: noop }) {
        const callbackInfo = {
            callback,
            options,
            disposer: () => {
                const idx = this.callbacks.indexOf(callbackInfo);
                if (idx > -1) {
                    this.callbacks.splice(idx, 1);
                    options.onCleanup();
                }
            }
        };
        this.callbacks.push(callbackInfo);
        if (!options.detached && getCurrentScope()) {
            onScopeDispose(callbackInfo.disposer);
        }
        return callbackInfo;
    }
    subscribe(callback, options = { detached: false, onCleanup: noop }) {
        const info = this.addSubscription(callback, options);
        return info.disposer;
    }
    trigger(...args) {
        this.callbacks.slice().forEach(({ callback }) => {
            callback(...args);
        });
    }
    triggerPiped(...args) {
        let resultArgs = args;
        this.callbacks.slice().forEach(({ callback }) => {
            resultArgs = callback.call(null, ...resultArgs);
        });
        return resultArgs;
    }
}
//# sourceMappingURL=Subscription.js.map